==> guayadeque_0.2.5.orig.tar.bz2: guayadeque-0.2.5/src/TaListBox.h <==
// -------------------------------------------------------------------------------- //
//	Copyright (C) 2008-2009 J.Rios
//	anonbeat@gmail.com
//
//    This Program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2, or (at your option)
//    any later version.
//
//    This Program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; see the file LICENSE.  If not, write to
//    the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
//    http://www.gnu.org/copyleft/gpl.html
//
// -------------------------------------------------------------------------------- //
#ifndef TALISTBOX_H
#define TALISTBOX_H

#include "ItemListBox.h"

// -------------------------------------------------------------------------------- //
class guTaListBox : public guListBox
{
  protected :
    virtual void    GetItemsList( void );
    virtual void    CreateContextMenu( wxMenu * Menu ) const;
    void            AddLabel( wxCommandEvent &event );
    void            DelLabel( wxCommandEvent &event );
    void            EditLabel( wxCommandEvent &event );

    virtual int     GetDragFiles( wxFileDataObject * files );

  public :

    guTaListBox( wxWindow * parent, guDbLibrary * NewDb, const wxString &Label );
    ~guTaListBox();

    virtual int GetSelectedSongs( guTrackArray * Songs ) const;

};

#endif
// -------------------------------------------------------------------------------- //

==> guayadeque_0.3.1~dfsg0.orig.tar.bz2: guayadeque-0.3.1~dfsg0/src/TaListBox.h <==
// -------------------------------------------------------------------------------- //
//	Copyright (C) 2008-2011 J.Rios
//	anonbeat@gmail.com
//
//    This Program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 3, or (at your option)
//    any later version.
//
//    This Program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; see the file LICENSE.  If not, write to
//    the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
//    http://www.gnu.org/copyleft/gpl.html
//
// -------------------------------------------------------------------------------- //
#ifndef TALISTBOX_H
#define TALISTBOX_H

#include "AccelListBox.h"

class guLibPanel;

// -------------------------------------------------------------------------------- //
class guTaListBox : public guAccelListBox
{
  protected :
    guLibPanel *    m_LibPanel;

    virtual void    GetItemsList( void );
    virtual void    CreateContextMenu( wxMenu * Menu ) const;
    void            AddLabel( wxCommandEvent &event );
    void            DelLabel( wxCommandEvent &event );
    void            EditLabel( wxCommandEvent &event );

    virtual int     GetDragFiles( wxFileDataObject * files );

    virtual void    CreateAcceleratorTable( void );

  public :

    guTaListBox( wxWindow * parent, guLibPanel * libpanel, guDbLibrary * NewDb, const wxString &Label );
    ~guTaListBox();

    virtual int GetSelectedSongs( guTrackArray * Songs ) const;

};

#endif
// -------------------------------------------------------------------------------- //
